@@ -1,5 +1,5 @@
 use std::os::raw::c_int;
-use viable_impl::vtable;
+use viable::vtable;
 
 // Just test syntax
 
@@ -12,5 +12,4 @@ struct Foo {
 	add2: extern "C" fn(a: c_int, b: c_int) -> c_int,
 }
 
-
 pub fn main() {}
\ No newline at end of file
